==> Saxon-HE-10.0-sources.jar: net/sf/saxon/functions/hof/FunctionName.java <==
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2020 Saxonica Limited
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
// This Source Code Form is "Incompatible With Secondary Licenses", as defined by the Mozilla Public License, v. 2.0.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

package net.sf.saxon.functions.hof;

import net.sf.saxon.expr.XPathContext;
import net.sf.saxon.functions.SystemFunction;
import net.sf.saxon.lib.NamespaceConstant;
import net.sf.saxon.om.Function;
import net.sf.saxon.om.Sequence;
import net.sf.saxon.om.StructuredQName;
import net.sf.saxon.om.ZeroOrOne;
import net.sf.saxon.trans.XPathException;
import net.sf.saxon.type.BuiltInAtomicType;
import net.sf.saxon.value.QNameValue;

/**
 * This class implements the function function-name(), which is a standard function in XPath 3.0
 */

public class FunctionName extends SystemFunction {

    /**
     * Evaluate the expression
     *
     * @param context   the dynamic evaluation context
     * @param arguments the values of the arguments, supplied as Sequence objects
     * @return the result of the evaluation, in the form of a Sequence
     * @throws net.sf.saxon.trans.XPathException
     *          if a dynamic error occurs during the evaluation of the expression
     */
    public ZeroOrOne call(XPathContext context, Sequence[] arguments) throws XPathException {
        Function f = (Function) arguments[0].head();
        assert f != null;
        StructuredQName name = f.getFunctionName();
        if (name == null) {
            return ZeroOrOne.empty();
        } else if (name.hasURI(NamespaceConstant.ANONYMOUS)) {
            // Used for inline functions
            return ZeroOrOne.empty();
        } else {
            QNameValue result = new QNameValue(name, BuiltInAtomicType.QNAME);
            return new ZeroOrOne(result);
        }
    }
}

// Copyright (c) 2012-2020 Saxonica Limited

==> Saxon-HE-11.5-sources.jar: net/sf/saxon/functions/hof/FunctionName.java <==
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2020 Saxonica Limited
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
// This Source Code Form is "Incompatible With Secondary Licenses", as defined by the Mozilla Public License, v. 2.0.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

package net.sf.saxon.functions.hof;

import net.sf.saxon.expr.XPathContext;
import net.sf.saxon.functions.SystemFunction;
import net.sf.saxon.lib.NamespaceConstant;
import net.sf.saxon.om.Function;
import net.sf.saxon.om.Sequence;
import net.sf.saxon.om.StructuredQName;
import net.sf.saxon.trans.XPathException;
import net.sf.saxon.type.BuiltInAtomicType;
import net.sf.saxon.value.EmptySequence;
import net.sf.saxon.value.QNameValue;

/**
 * This class implements the function function-name(), which is a standard function in XPath 3.0
 */

public class FunctionName extends SystemFunction {

    /**
     * Evaluate the expression
     *
     * @param context   the dynamic evaluation context
     * @param arguments the values of the arguments, supplied as Sequence objects
     * @return the result of the evaluation, in the form of a Sequence
     * @throws net.sf.saxon.trans.XPathException
     *          if a dynamic error occurs during the evaluation of the expression
     */
    @Override
    public Sequence call(XPathContext context, Sequence[] arguments) throws XPathException {
        Function f = (Function) arguments[0].head();
        assert f != null;
        StructuredQName name = f.getFunctionName();
        if (name == null) {
            return EmptySequence.getInstance();
        } else if (name.hasURI(NamespaceConstant.ANONYMOUS)) {
            // Used for inline functions
            return EmptySequence.getInstance();
        } else {
            return new QNameValue(name, BuiltInAtomicType.QNAME);
        }
    }
}

// Copyright (c) 2012-2022 Saxonica Limited
